@@ -25,6 +25,8 @@
 #include "e-contact-list-editor.h"
 #include <e-util/e-util-private.h>
 #include <e-util/e-alert-dialog.h>
+#include <e-util/e-selection.h>
+#include <e-util/gtk-compat.h>
 #include "shell/e-shell.h"
 
 #include <string.h>
@@ -33,6 +35,7 @@
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
 
+#include <camel/camel.h>
 #include <libedataserverui/e-source-combo-box.h>
 
 #include "e-util/e-util.h"
@@ -127,16 +130,6 @@ struct _EContactListEditorPrivate {
 	EBook *load_book;
 };
 
-#define VCARD_TYPE "text/x-vcard"
-
-enum {
-	TARGET_TYPE_VCARD
-};
-
-static GtkTargetEntry targets[] = {
-	{ (gchar *) VCARD_TYPE, 0, TARGET_TYPE_VCARD },
-};
-
 static gpointer parent_class;
 
 static EContactListEditor *
@@ -215,18 +208,19 @@ contact_list_editor_add_email (EContactListEditor *editor)
 
 static void
 contact_list_editor_book_loaded (EBook *new_book,
-                                 EBookStatus status,
+                                 const GError *error,
                                  EContactListEditor *editor)
 {
 	EContactListEditorPrivate *priv = editor->priv;
+	EContactStore *contact_store;
 	ENameSelectorEntry *entry;
 
 	priv->load_source_id = 0;
 	priv->load_book = NULL;
 
-	if (status != E_BOOK_ERROR_OK || new_book == NULL) {
+	if (error || new_book == NULL) {
 		eab_load_error_dialog (
-			NULL, e_book_get_source (new_book), status);
+			NULL, e_book_get_source (new_book), error);
 		e_source_combo_box_set_active (
 			E_SOURCE_COMBO_BOX (WIDGET (SOURCE_MENU)),
 			e_book_get_source (priv->book));
@@ -236,7 +230,8 @@ contact_list_editor_book_loaded (EBook *new_book,
 	}
 
 	entry = E_NAME_SELECTOR_ENTRY (WIDGET (EMAIL_ENTRY));
-	e_contact_store_add_book (entry->contact_store, new_book);
+	contact_store = e_name_selector_entry_peek_contact_store (entry);
+	e_contact_store_add_book (contact_store, new_book);
 	e_contact_list_editor_set_book (editor, new_book);
 	g_object_unref (new_book);
 }
@@ -271,7 +266,7 @@ contact_list_editor_contact_exists (EContactListModel *model,
 
 static void
 contact_list_editor_list_added_cb (EBook *book,
-                                   EBookStatus status,
+                                   const GError *error,
                                    const gchar *id,
                                    EditorCloseStruct *ecs)
 {
@@ -285,9 +280,9 @@ contact_list_editor_list_added_cb (EBook *book,
 	e_contact_set (priv->contact, E_CONTACT_UID, (gchar *) id);
 
 	eab_editor_contact_added (
-		EAB_EDITOR (editor), status, priv->contact);
+		EAB_EDITOR (editor), error, priv->contact);
 
-	if (status == E_BOOK_ERROR_OK) {
+	if (!error) {
 		priv->is_new_list = FALSE;
 
 		if (should_close)
@@ -302,7 +297,7 @@ contact_list_editor_list_added_cb (EBook *book,
 
 static void
 contact_list_editor_list_modified_cb (EBook *book,
-                                      EBookStatus status,
+                                      const GError *error,
                                       EditorCloseStruct *ecs)
 {
 	EContactListEditor *editor = ecs->editor;
@@ -313,9 +308,9 @@ contact_list_editor_list_modified_cb (EBook *book,
 	priv->in_async_call = FALSE;
 
 	eab_editor_contact_modified (
-		EAB_EDITOR (editor), status, priv->contact);
+		EAB_EDITOR (editor), error, priv->contact);
 
-	if (status == E_BOOK_ERROR_OK) {
+	if (!error) {
 		if (should_close)
 			eab_editor_close (EAB_EDITOR (editor));
 	}
@@ -439,27 +434,37 @@ contact_list_editor_drag_data_received_cb (GtkWidget *widget,
 void
 contact_list_editor_drag_data_received_cb (GtkWidget *widget,
                                            GdkDragContext *context,
-                                             gint x, gint y,
-                                             GtkSelectionData *selection_data,
-                                             guint info,
-                                             guint time)
+                                           gint x, gint y,
+                                           GtkSelectionData *selection_data,
+                                           guint info,
+                                           guint time)
 {
+	CamelInternetAddress *address;
 	EContactListEditor *editor;
 	EContactListModel *model;
-	gchar *target_type;
 	gboolean changed = FALSE;
 	gboolean handled = FALSE;
+	const guchar *data;
 	GList *list, *iter;
+	GdkAtom target;
+	gint n_addresses = 0;
+	gchar *text;
 
 	editor = contact_list_editor_extract (widget);
-
 	model = E_CONTACT_LIST_MODEL (editor->priv->model);
-	target_type = gdk_atom_name (selection_data->target);
 
-	if (strcmp (target_type, VCARD_TYPE) != 0)
+	target = gtk_selection_data_get_target (selection_data);
+
+	/* Sanity check the selection target. */
+
+	if (gtk_targets_include_text (&target, 1))
+		goto handle_text;
+
+	if (!e_targets_include_directory (&target, 1))
 		goto exit;
 
-	list = eab_contact_list_from_string ((gchar *) selection_data->data);
+	data = gtk_selection_data_get_data (selection_data);
+	list = eab_contact_list_from_string ((gchar *) data);
 
 	if (list != NULL)
 		handled = TRUE;
@@ -496,80 +501,43 @@ contact_list_editor_drag_data_received_cb (GtkWidget *widget,
 		contact_list_editor_update (editor);
 	}
 
+	goto exit;
+
+handle_text:
+
+	address = camel_internet_address_new ();
+	text = (gchar *) gtk_selection_data_get_text (selection_data);
+
+	/* See if Camel can parse a valid email address from the text. */
+	if (text != NULL && *text != '\0') {
+		camel_url_decode (text);
+		if (g_ascii_strncasecmp (text, "mailto:", 7) == 0)
+			n_addresses = camel_address_decode (
+				CAMEL_ADDRESS (address), text + 7);
+		else
+			n_addresses = camel_address_decode (
+				CAMEL_ADDRESS (address), text);
+	}
+
+	if (n_addresses == 1) {
+		g_free (text);
+
+		text = camel_address_format (CAMEL_ADDRESS (address));
+		e_contact_list_model_add_email (model, text);
+
+		contact_list_editor_scroll_to_end (editor);
+		editor->priv->changed = TRUE;
+
+		contact_list_editor_update (editor);
+		handled = TRUE;
+	}
+
+	g_free (text);
+
 exit:
 	gtk_drag_finish (context, handled, FALSE, time);
 }
 
-gboolean
-contact_list_editor_drag_drop_cb (GtkWidget *widget,
-                                  GdkDragContext *context,
-                                  gint x, gint y,
-                                  guint time);
-
-gboolean
-contact_list_editor_drag_drop_cb (GtkWidget *widget,
-                                  GdkDragContext *context,
-                                  gint x, gint y,
-                                  guint time)
-{
-	EContactListEditor *editor;
-	GList *iter;
-
-	editor = contact_list_editor_extract (widget);
-
-	for (iter = context->targets; iter != NULL; iter = iter->next) {
-		GdkAtom target = GDK_POINTER_TO_ATOM (iter->data);
-		gchar *possible_type;
-		gboolean match;
-
-		possible_type = gdk_atom_name (target);
-		match = (strcmp (possible_type, VCARD_TYPE) == 0);
-		g_free (possible_type);
-
-		if (match) {
-			gtk_drag_get_data (widget, context, target, time);
-			return TRUE;
-		}
-	}
-
-	return FALSE;
-}
-
-gboolean
-contact_list_editor_drag_motion_cb (GtkWidget *widget,
-                                    GdkDragContext *context,
-                                    gint x, gint y,
-                                    guint time);
-
-gboolean
-contact_list_editor_drag_motion_cb (GtkWidget *widget,
-                                    GdkDragContext *context,
-                                    gint x, gint y,
-                                    guint time)
-{
-	EContactListEditor *editor;
-	GList *iter;
-
-	editor = contact_list_editor_extract (widget);
-
-	for (iter = context->targets; iter != NULL; iter = iter->next) {
-		GdkAtom target = GDK_POINTER_TO_ATOM (iter->data);
-		gchar *possible_type;
-		gboolean match;
-
-		possible_type = gdk_atom_name (target);
-		match = (strcmp (possible_type, VCARD_TYPE) == 0);
-		g_free (possible_type);
-
-		if (match) {
-			gdk_drag_status (context, GDK_ACTION_LINK, time);
-			return TRUE;
-		}
-	}
-
-	return FALSE;
-}
-
 void
 contact_list_editor_email_entry_activate_cb (GtkWidget *widget);
 
@@ -666,7 +634,7 @@ contact_list_editor_email_entry_updated_cb (GtkWidget *widget,
 	entry = E_NAME_SELECTOR_ENTRY (widget);
 	model = E_CONTACT_LIST_MODEL (editor->priv->model);
 
-	email = g_strdup (e_destination_get_address (destination));
+	email = g_strdup (e_destination_get_textrep (destination, TRUE));
 	store = e_name_selector_entry_peek_destination_store (entry);
 	e_destination_store_remove_destination (store, destination);
 	gtk_entry_set_text (GTK_ENTRY (WIDGET (EMAIL_ENTRY)), "");
@@ -783,6 +751,7 @@ contact_list_editor_select_button_clicked_cb (GtkWidget *widget)
 	ENameSelectorDialog *dialog;
 	EDestinationStore *store;
 	GList *list, *iter;
+	GtkWindow *window;
 
 	editor = contact_list_editor_extract (widget);
 
@@ -806,6 +775,9 @@ contact_list_editor_select_button_clicked_cb (GtkWidget *widget)
 
 	g_list_free (list);
 
+	window = eab_editor_get_window (EAB_EDITOR (editor));
+	e_name_selector_show_dialog (
+		editor->priv->name_selector, GTK_WIDGET (window));
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_hide (GTK_WIDGET (dialog));
 
@@ -846,7 +818,7 @@ contact_list_editor_source_menu_changed_cb (GtkWidget *widget)
 
 	editor->priv->load_book = e_book_new (source, NULL);
 	editor->priv->load_source_id = addressbook_load (
-		editor->priv->load_book, (EBookCallback)
+		editor->priv->load_book, (EBookAsyncCallback)
 		contact_list_editor_book_loaded, editor);
 }
 
@@ -1114,7 +1086,10 @@ contact_list_editor_close (EABEditor *editor)
 static void
 contact_list_editor_raise (EABEditor *editor)
 {
-	gdk_window_raise (WIDGET (DIALOG)->window);
+	GdkWindow *window;
+
+	window = gtk_widget_get_window (WIDGET (DIALOG));
+	gdk_window_raise (window);
 }
 
 static void
@@ -1140,11 +1115,11 @@ contact_list_editor_save_contact (EABEditor *eab_editor,
 
 	if (priv->is_new_list)
 		eab_merging_book_add_contact (
-			priv->book, contact, (EBookIdCallback)
+			priv->book, contact, (EBookIdAsyncCallback)
 			contact_list_editor_list_added_cb, ecs);
 	else
 		eab_merging_book_commit_contact (
-			priv->book, contact, (EBookCallback)
+			priv->book, contact, (EBookAsyncCallback)
 			contact_list_editor_list_modified_cb, ecs);
 
 	priv->changed = FALSE;
@@ -1179,44 +1154,44 @@ contact_list_editor_get_window (EABEditor *editor)
 
 static void
 contact_list_editor_contact_added (EABEditor *editor,
-                                   EBookStatus status,
+                                   const GError *error,
                                    EContact *contact)
 {
-	if (status == E_BOOK_ERROR_OK)
+	if (!error)
 		return;
 
-	if (status == E_BOOK_ERROR_CANCELLED)
+	if (g_error_matches (error, E_BOOK_ERROR, E_BOOK_ERROR_CANCELLED))
 		return;
 
-	eab_error_dialog (_("Error adding list"), status);
+	eab_error_dialog (_("Error adding list"), error);
 }
 
 static void
 contact_list_editor_contact_modified (EABEditor *editor,
-                                      EBookStatus status,
+                                      const GError *error,
                                       EContact *contact)
 {
-	if (status == E_BOOK_ERROR_OK)
+	if (!error)
 		return;
 
-	if (status == E_BOOK_ERROR_CANCELLED)
+	if (g_error_matches (error, E_BOOK_ERROR, E_BOOK_ERROR_CANCELLED))
 		return;
 
-	eab_error_dialog (_("Error modifying list"), status);
+	eab_error_dialog (_("Error modifying list"), error);
 }
 
 static void
 contact_list_editor_contact_deleted (EABEditor *editor,
-                                     EBookStatus status,
+                                     const GError *error,
                                      EContact *contact)
 {
-	if (status == E_BOOK_ERROR_OK)
+	if (!error)
 		return;
 
-	if (status == E_BOOK_ERROR_CANCELLED)
+	if (g_error_matches (error, E_BOOK_ERROR, E_BOOK_ERROR_CANCELLED))
 		return;
 
-	eab_error_dialog (_("Error removing list"), status);
+	eab_error_dialog (_("Error removing list"), error);
 }
 
 static void
@@ -1260,8 +1235,8 @@ contact_list_editor_class_init (EContactListEditorClass *class)
 		PROP_BOOK,
 		g_param_spec_object (
 			"book",
-			_("Book"),
-			/*_( */"XXX blurb" /*)*/,
+			"Book",
+			NULL,
 			E_TYPE_BOOK,
 			G_PARAM_READWRITE));
 
@@ -1270,8 +1245,8 @@ contact_list_editor_class_init (EContactListEditorClass *class)
 		PROP_CONTACT,
 		g_param_spec_object (
 			"contact",
-			_("Contact"),
-			/*_( */"XXX blurb" /*)*/,
+			"Contact",
+			NULL,
 			E_TYPE_CONTACT,
 			G_PARAM_READWRITE));
 
@@ -1280,8 +1255,8 @@ contact_list_editor_class_init (EContactListEditorClass *class)
 		PROP_IS_NEW_LIST,
 		g_param_spec_boolean (
 			"is_new_list",
-			_("Is New List"),
-			/*_( */"XXX blurb" /*)*/,
+			"Is New List",
+			NULL,
 			FALSE,
 			G_PARAM_READWRITE));
 
@@ -1290,8 +1265,8 @@ contact_list_editor_class_init (EContactListEditorClass *class)
 		PROP_EDITABLE,
 		g_param_spec_boolean (
 			"editable",
-			_("Editable"),
-			/*_( */"XXX blurb" /*)*/,
+			"Editable",
+			NULL,
 			FALSE,
 			G_PARAM_READWRITE));
 }
@@ -1324,8 +1299,10 @@ contact_list_editor_init (EContactListEditor *editor)
 
 	gtk_tree_selection_set_mode (
 		gtk_tree_view_get_selection (view), GTK_SELECTION_MULTIPLE);
-	gtk_tree_view_enable_model_drag_dest (
-		view, targets, G_N_ELEMENTS (targets), GDK_ACTION_LINK);
+
+	gtk_tree_view_enable_model_drag_dest (view, NULL, 0, GDK_ACTION_LINK);
+	e_drag_dest_add_directory_targets (WIDGET (TREE_VIEW));
+	gtk_drag_dest_add_text_targets (WIDGET (TREE_VIEW));
 
 	g_signal_connect (
 		priv->model, "row-deleted",
