@@ -36,7 +36,6 @@
 #include <stdio.h>
 #include <time.h>
 
-#include <libedataserver/e-data-server-util.h>
 #include "e-util.h"
 #include "e-mktemp.h"
 
@@ -69,7 +68,7 @@ expire_dir_rec(const gchar *base, time_t now)
 	path = g_string_new(base);
 	len = path->len;
 
-	while ( (d = g_dir_read_name(dir)) ) {
+	while ((d = g_dir_read_name(dir))) {
 		g_string_truncate(path, len);
 		g_string_append_printf(path, "/%s", d);
 		d(printf("Checking '%s' for expiry\n", path->str));
@@ -109,9 +108,11 @@ get_dir (gboolean make)
 	static time_t last = 0;
 
 #ifdef TEMP_HOME
-	gchar *tmpdir = NULL;
-	tmpdir = g_build_filename(e_get_user_data_dir (),
-		"cache", "tmp", NULL);
+	const gchar *user_cache_dir;
+	gchar *tmpdir;
+
+	user_cache_dir = e_get_user_cache_dir ();
+	tmpdir = g_build_filename (user_cache_dir, "tmp", NULL);
 	path = g_string_new(tmpdir);
 	if (make && g_mkdir_with_parents(tmpdir, 0777) == -1) {
 		g_string_free(path, TRUE);
@@ -167,7 +168,7 @@ gchar *
 e_mktemp (const gchar *template)
 {
 	GString *path;
-	gchar *ret;
+	gint fd;
 
 	path = get_dir (TRUE);
 	if (!path)
@@ -179,10 +180,14 @@ e_mktemp (const gchar *template)
 	else
 		g_string_append (path, "unknown-XXXXXX");
 
-	ret = mktemp (path->str);
-	g_string_free(path, ret == NULL);
+	fd = g_mkstemp (path->str);
 
-	return ret;
+	if (fd != -1) {
+		close (fd);
+		g_unlink (path->str);
+	}
+
+	return g_string_free (path, fd == -1);
 }
 
 gint
@@ -226,7 +231,17 @@ e_mkdtemp (const gchar *template)
 #ifdef HAVE_MKDTEMP
 	tmpdir = mkdtemp (path->str);
 #else
-	tmpdir = mktemp (path->str);
+	{
+		gint fd = g_mkstemp (path->str);
+		if (fd == -1) {
+			tmpdir = NULL;
+		} else {
+			close (fd);
+			tmpdir = path->str;
+			g_unlink (tmpdir);
+		}
+	}
+
 	if (tmpdir) {
 		if (g_mkdir (tmpdir, S_IRWXU) == -1)
 			tmpdir = NULL;
