@@ -99,6 +99,7 @@ struct _EMailReaderIface {
 						 const gchar *folder_uri);
 	void		(*set_message)		(EMailReader *reader,
 						 const gchar *uid);
+	guint		(*open_selected_mail)	(EMailReader *reader);
 
 	/* Signals */
 	void		(*show_search_bar)	(EMailReader *reader);
@@ -108,6 +109,7 @@ struct _EMailReaderIface {
 
 GType		e_mail_reader_get_type		(void);
 void		e_mail_reader_init		(EMailReader *reader);
+void		e_mail_reader_init_private (EMailReader *reader);
 void		e_mail_reader_changed		(EMailReader *reader);
 guint32		e_mail_reader_check_state	(EMailReader *reader);
 void		e_mail_reader_update_actions	(EMailReader *reader,
@@ -119,6 +121,7 @@ GtkActionGroup *
 EMFormatHTML *	e_mail_reader_get_formatter	(EMailReader *reader);
 gboolean	e_mail_reader_get_hide_deleted	(EMailReader *reader);
 GtkWidget *	e_mail_reader_get_message_list	(EMailReader *reader);
+guint		e_mail_reader_open_selected_mail(EMailReader *reader);
 GtkMenu *	e_mail_reader_get_popup_menu	(EMailReader *reader);
 GPtrArray *	e_mail_reader_get_selected_uids	(EMailReader *reader);
 EShellBackend *	e_mail_reader_get_shell_backend	(EMailReader *reader);
