@@ -193,6 +193,13 @@ folder_tree_get_folder_info__exec (struct _EMFolderTreeGetFolderInfo *m)
 
 	m->fi = camel_store_get_folder_info (
 		m->store, m->top, flags, &m->base.error);
+
+	/* XXX POP3 stores always return an error because they have
+	 *     no folder hierarchy to scan.  Clear that error so the
+	 *     user doesn't see it. */
+	if (g_error_matches (m->base.error,
+		CAMEL_STORE_ERROR, CAMEL_STORE_ERROR_NO_FOLDER))
+		g_clear_error (&m->base.error);
 }
 
 static void
@@ -2881,6 +2888,7 @@ em_folder_tree_restore_state (EMFolderTree *folder_tree,
 
 	while (valid) {
 		const gchar *key = STATE_KEY_EXPANDED;
+		gboolean expand_row;
 		gchar *group_name;
 		gchar *uri;
 
@@ -2892,22 +2900,17 @@ em_folder_tree_restore_state (EMFolderTree *folder_tree,
 
 		group_name = g_strdup_printf ("Store %s", uri);
 
+		/* Expand stores that have no "Expanded" key. */
+		expand_row = !g_key_file_has_key (
+			key_file, group_name, key, NULL);
+
+		/* Do not expand local stores in Express mode. */
 		if (e_shell_get_express_mode (shell)) {
-			gboolean system = FALSE;
+			expand_row &= (strncmp (uri, "vfolder", 7) != 0);
+			expand_row &= (strncmp (uri, "mbox", 4) != 0);
+		}
 
-			if (strncmp (uri, "vfolder", 7) == 0 ||
-					strncmp(uri, "mbox", 4) == 0)
-				system = TRUE;
-
-			if (!system && !g_key_file_has_key (key_file, group_name, key, NULL)) {
-				GtkTreePath *path;
-
-				path = gtk_tree_model_get_path (tree_model, &iter);
-				gtk_tree_view_expand_row (tree_view, path, FALSE);
-				gtk_tree_path_free (path);
-			}
-
-		} else if (!g_key_file_has_key (key_file, group_name, key, NULL)) {
+		if (expand_row) {
 			GtkTreePath *path;
 
 			path = gtk_tree_model_get_path (tree_model, &iter);
