@@ -48,17 +48,13 @@
 #include "e-cal-shell-content.h"
 #include "e-cal-shell-migrate.h"
 #include "e-cal-shell-settings.h"
+#include "e-cal-shell-sidebar.h"
 #include "e-cal-shell-view.h"
 
 #define E_CAL_SHELL_BACKEND_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
 	((obj), E_TYPE_CAL_SHELL_BACKEND, ECalShellBackendPrivate))
 
-#define CONTACTS_BASE_URI	"contacts://"
-#define WEATHER_BASE_URI	"weather://"
-#define WEB_BASE_URI		"webcal://"
-#define PERSONAL_RELATIVE_URI	"system"
-
 struct _ECalShellBackendPrivate {
 	ESourceList *source_list;
 };
@@ -84,9 +80,8 @@ cal_shell_backend_ensure_sources (EShellBackend *shell_backend)
 	ESource *personal;
 	EShell *shell;
 	EShellSettings *shell_settings;
-	const gchar *data_dir, *name;
-	gchar *base_uri, base_uri_seventh;
-	gchar *filename;
+	GSList *sources, *iter;
+	const gchar *name;
 	gchar *property;
 	gboolean save_list = FALSE;
 
@@ -103,78 +98,30 @@ cal_shell_backend_ensure_sources (EShellBackend *shell_backend)
 		return;
 	}
 
-	data_dir = e_shell_backend_get_data_dir (shell_backend);
-	filename = g_build_filename (data_dir, "local", NULL);
-	base_uri = g_filename_to_uri (filename, NULL, NULL);
-	g_free (filename);
-
-	if (strlen (base_uri) > 7) {
-		/* Compare only file:// part. If user home dir name
-		 * changes we do not want to create one more group. */
-		base_uri_seventh = base_uri[7];
-		base_uri[7] = 0;
-	} else {
-		base_uri_seventh = -1;
-	}
-
 	on_this_computer = e_source_list_ensure_group (
-		priv->source_list, _("On This Computer"), base_uri, TRUE);
+		priv->source_list, _("On This Computer"), "local:", TRUE);
 	contacts = e_source_list_ensure_group (
-		priv->source_list, _("Contacts"), CONTACTS_BASE_URI, TRUE);
+		priv->source_list, _("Contacts"), "contacts://", TRUE);
 	e_source_list_ensure_group (
-		priv->source_list, _("On The Web"), WEB_BASE_URI, FALSE);
+		priv->source_list, _("On The Web"), "webcal://", FALSE);
 	e_source_list_ensure_group (
-		priv->source_list, _("Weather"), WEATHER_BASE_URI, FALSE);
+		priv->source_list, _("Weather"), "weather://", FALSE);
 
-	if (base_uri_seventh != -1) {
-		base_uri[7] = base_uri_seventh;
-	}
+	g_return_if_fail (on_this_computer != NULL);
+	g_return_if_fail (contacts != NULL);
 
-	name = _("On This Computer");
+	sources = e_source_group_peek_sources (on_this_computer);
 
-	if (on_this_computer != NULL) {
-		GSList *sources, *iter;
-		const gchar *group_base_uri;
-
-		sources = e_source_group_peek_sources (on_this_computer);
-		group_base_uri = e_source_group_peek_base_uri (on_this_computer);
-
-		/* Make sure this group includes a "Personal" source. */
-		for (iter = sources; iter != NULL; iter = iter->next) {
-			ESource *source = iter->data;
-			const gchar *relative_uri;
-
-			relative_uri = e_source_peek_relative_uri (source);
-			if (relative_uri == NULL)
-				continue;
-
-			if (strcmp (PERSONAL_RELATIVE_URI, relative_uri) != 0)
-				continue;
+	/* Make sure this group includes a "Personal" source. */
+	for (iter = sources; iter != NULL; iter = iter->next) {
+		ESource *source = iter->data;
+		const gchar *relative_uri;
 
+		relative_uri = e_source_peek_relative_uri (source);
+		if (g_strcmp0 (relative_uri, "system") == 0) {
 			personal = source;
 			break;
 		}
-
-		/* Make sure we have the correct base URI.  This can
-		 * change when the user's home directory changes. */
-		if (strcmp (base_uri, group_base_uri) != 0) {
-			e_source_group_set_base_uri (
-				on_this_computer, base_uri);
-
-			/* XXX We shouldn't need this sync call here as
-			 *     set_base_uri() results in synching to GConf,
-			 *     but that happens in an idle loop and too late
-			 *     to prevent the user from seeing a "Cannot
-			 *     Open ... because of invalid URI" error. */
-			save_list = TRUE;
-		}
-	} else {
-		ESourceGroup *source_group;
-
-		source_group = e_source_group_new (name, base_uri);
-		e_source_list_add_group (priv->source_list, source_group, -1);
-		on_this_computer = source_group;
-		g_object_unref (source_group);
 	}
 
 	name = _("Personal");
@@ -184,7 +131,7 @@ cal_shell_backend_ensure_sources (EShellBackend *shell_backend)
 		GSList *selected;
 		gchar *primary;
 
-		source = e_source_new (name, PERSONAL_RELATIVE_URI);
+		source = e_source_new (name, "system");
 		e_source_set_color_spec (source, "#BECEDD");
 		e_source_group_add_source (on_this_computer, source, -1);
 		g_object_unref (source);
@@ -214,29 +161,24 @@ cal_shell_backend_ensure_sources (EShellBackend *shell_backend)
 		e_source_set_name (personal, name);
 	}
 
-	if (contacts != NULL) {
-		GSList *sources;
+	sources = e_source_group_peek_sources (contacts);
 
-		sources = e_source_group_peek_sources (contacts);
+	if (sources != NULL) {
+		GSList *trash;
 
-		if (sources != NULL) {
-			GSList *trash;
-
-			/* There is only one source under Contacts. */
-			birthdays = E_SOURCE (sources->data);
-			sources = g_slist_next (sources);
-
-			/* Delete any other sources in this group.
-			 * Earlier versions allowed you to create
-			 * additional sources under Contacts. */
-			trash = g_slist_copy (sources);
-			while (trash != NULL) {
-				ESource *source = trash->data;
-				e_source_group_remove_source (contacts, source);
-				trash = g_slist_delete_link (trash, trash);
-				save_list = TRUE;
-			}
+		/* There is only one source under Contacts. */
+		birthdays = E_SOURCE (sources->data);
+		sources = g_slist_next (sources);
 
+		/* Delete any other sources in this group.
+		 * Earlier versions allowed you to create
+		 * additional sources under Contacts. */
+		trash = g_slist_copy (sources);
+		while (trash != NULL) {
+			ESource *source = trash->data;
+			e_source_group_remove_source (contacts, source);
+			trash = g_slist_delete_link (trash, trash);
+			save_list = TRUE;
 		}
 	}
 
@@ -273,7 +215,6 @@ cal_shell_backend_ensure_sources (EShellBackend *shell_backend)
 
 	g_object_unref (on_this_computer);
 	g_object_unref (contacts);
-	g_free (base_uri);
 
 	if (save_list)
 		e_source_list_sync (priv->source_list, NULL);
@@ -281,7 +222,7 @@ cal_shell_backend_ensure_sources (EShellBackend *shell_backend)
 
 static void
 cal_shell_backend_new_event (ECal *cal,
-                             ECalendarStatus status,
+                             const GError *error,
                              EShell *shell,
                              CompEditorFlags flags,
                              gboolean all_day)
@@ -290,7 +231,7 @@ cal_shell_backend_new_event (ECal *cal,
 	CompEditor *editor;
 
 	/* XXX Handle errors better. */
-	if (status != E_CALENDAR_STATUS_OK)
+	if (error)
 		return;
 
 	flags |= COMP_EDITOR_NEW_ITEM;
@@ -307,39 +248,39 @@ cal_shell_backend_new_event (ECal *cal,
 
 static void
 cal_shell_backend_event_new_cb (ECal *cal,
-                                ECalendarStatus status,
+                                const GError *error,
                                 EShell *shell)
 {
 	CompEditorFlags flags;
 
 	flags = COMP_EDITOR_USER_ORG;
-	cal_shell_backend_new_event (cal, status, shell, flags, FALSE);
+	cal_shell_backend_new_event (cal, error, shell, flags, FALSE);
 
 	g_object_unref (cal);
 }
 
 static void
 cal_shell_backend_event_all_day_new_cb (ECal *cal,
-                                        ECalendarStatus status,
+                                        const GError *error,
                                         EShell *shell)
 {
 	CompEditorFlags flags;
 
 	flags = COMP_EDITOR_USER_ORG;
-	cal_shell_backend_new_event (cal, status, shell, flags, TRUE);
+	cal_shell_backend_new_event (cal, error, shell, flags, TRUE);
 
 	g_object_unref (cal);
 }
 
 static void
 cal_shell_backend_event_meeting_new_cb (ECal *cal,
-                                        ECalendarStatus status,
+                                        const GError *error,
                                         EShell *shell)
 {
 	CompEditorFlags flags;
 
 	flags = COMP_EDITOR_USER_ORG | COMP_EDITOR_MEETING;
-	cal_shell_backend_new_event (cal, status, shell, flags, FALSE);
+	cal_shell_backend_new_event (cal, error, shell, flags, FALSE);
 
 	g_object_unref (cal);
 }
@@ -424,17 +365,17 @@ action_event_new_cb (GtkAction *action,
 	action_name = gtk_action_get_name (action);
 	if (strcmp (action_name, "event-all-day-new") == 0)
 		g_signal_connect (
-			cal, "cal-opened",
+			cal, "cal-opened-ex",
 			G_CALLBACK (cal_shell_backend_event_all_day_new_cb),
 			shell);
 	else if (strcmp (action_name, "event-meeting-new") == 0)
 		g_signal_connect (
-			cal, "cal-opened",
+			cal, "cal-opened-ex",
 			G_CALLBACK (cal_shell_backend_event_meeting_new_cb),
 			shell);
 	else
 		g_signal_connect (
-			cal, "cal-opened",
+			cal, "cal-opened-ex",
 			G_CALLBACK (cal_shell_backend_event_new_cb),
 			shell);
 
@@ -539,6 +480,8 @@ cal_shell_backend_handle_uri_cb (EShellBackend *shell_backend,
 	gchar *source_uid = NULL;
 	gchar *comp_uid = NULL;
 	gchar *comp_rid = NULL;
+	GDate start_date;
+	GDate end_date;
 	gboolean handled = FALSE;
 	GError *error = NULL;
 
@@ -553,6 +496,9 @@ cal_shell_backend_handle_uri_cb (EShellBackend *shell_backend,
 	if (cp == NULL)
 		goto exit;
 
+	g_date_clear (&start_date, 1);
+	g_date_clear (&end_date, 1);
+
 	while (*cp != '\0') {
 		gchar *header;
 		gchar *content;
@@ -572,7 +518,13 @@ cal_shell_backend_handle_uri_cb (EShellBackend *shell_backend,
 		content_len = strcspn (cp, "&");
 
 		content = g_strndup (cp, content_len);
-		if (g_ascii_strcasecmp (header, "source-uid") == 0)
+		if (g_ascii_strcasecmp (header, "startdate") == 0)
+			g_date_set_time_t (
+				&start_date, time_from_isodate (content));
+		else if (g_ascii_strcasecmp (header, "enddate") == 0)
+			g_date_set_time_t (
+				&end_date, time_from_isodate (content));
+		else if (g_ascii_strcasecmp (header, "source-uid") == 0)
 			source_uid = g_strdup (content);
 		else if (g_ascii_strcasecmp (header, "comp-uid") == 0)
 			comp_uid = g_strdup (content);
@@ -588,6 +540,21 @@ cal_shell_backend_handle_uri_cb (EShellBackend *shell_backend,
 		}
 	}
 
+	/* This is primarily for launching Evolution
+	 * from the calendar in the clock applet. */
+	if (g_date_valid (&start_date)) {
+		if (g_date_valid (&end_date))
+			e_cal_shell_backend_open_date_range (
+				E_CAL_SHELL_BACKEND (shell_backend),
+				&start_date, &end_date);
+		else
+			e_cal_shell_backend_open_date_range (
+				E_CAL_SHELL_BACKEND (shell_backend),
+				&start_date, NULL);
+		handled = TRUE;
+		goto exit;
+	}
+
 	if (source_uid == NULL || comp_uid == NULL)
 		goto exit;
 
@@ -831,3 +798,57 @@ e_cal_shell_backend_get_source_list (ECalShellBackend *cal_shell_backend)
 
 	return cal_shell_backend->priv->source_list;
 }
+
+void
+e_cal_shell_backend_open_date_range (ECalShellBackend *cal_shell_backend,
+                                     const GDate *start_date,
+                                     const GDate *end_date)
+{
+	EShell *shell;
+	EShellView *shell_view;
+	EShellBackend *shell_backend;
+	EShellSidebar *shell_sidebar;
+	GtkWidget *shell_window = NULL;
+	ECalendar *navigator;
+	GList *watched_windows;
+
+	g_return_if_fail (E_IS_CAL_SHELL_BACKEND (cal_shell_backend));
+
+	shell_backend = E_SHELL_BACKEND (cal_shell_backend);
+	shell = e_shell_backend_get_shell (shell_backend);
+	watched_windows = e_shell_get_watched_windows (shell);
+
+	/* Try to find an EShellWindow already in calendar view. */
+	while (watched_windows != NULL) {
+		GtkWidget *window = GTK_WIDGET (watched_windows->data);
+
+		if (E_IS_SHELL_WINDOW (window)) {
+			const gchar *active_view;
+
+			active_view = e_shell_window_get_active_view (
+				E_SHELL_WINDOW (window));
+			if (g_strcmp0 (active_view, "calendar") == 0) {
+				gtk_window_present (GTK_WINDOW (window));
+				shell_window = window;
+				break;
+			}
+		}
+
+		watched_windows = g_list_next (watched_windows);
+	}
+
+	/* Otherwise create a new EShellWindow in calendar view. */
+	if (shell_window == NULL)
+		shell_window = e_shell_create_shell_window (shell, "calendar");
+
+	/* Now dig up the date navigator and select the date range. */
+
+	shell_view = e_shell_window_get_shell_view (
+		E_SHELL_WINDOW (shell_window), "calendar");
+	shell_sidebar = e_shell_view_get_shell_sidebar (shell_view);
+	navigator = e_cal_shell_sidebar_get_date_navigator (
+		E_CAL_SHELL_SIDEBAR (shell_sidebar));
+
+	e_calendar_item_set_selection (
+		navigator->calitem, start_date, end_date);
+}
