@@ -37,7 +37,7 @@ mail_shell_view_folder_tree_selected_cb (EMailShellView *mail_shell_view,
 	gboolean folder_selected;
 
 	shell_view = E_SHELL_VIEW (mail_shell_view);
-	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content);
+	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content->view);
 
 	folder_selected =
 		!(flags & CAMEL_FOLDER_NOSELECT) &&
@@ -89,7 +89,7 @@ ctrl:
 
 emit:
 	/* Forward the key press to the EMailReader interface. */
-	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content);
+	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content->view);
 	g_signal_emit_by_name (reader, "key-press-event", event, &handled);
 
 exit:
@@ -107,7 +107,7 @@ mail_shell_view_folder_tree_selection_done_cb (EMailShellView *mail_shell_view,
 	const gchar *list_uri;
 	gchar *tree_uri;
 
-	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content);
+	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content->view);
 	message_list = e_mail_reader_get_message_list (reader);
 
 	mail_shell_sidebar = mail_shell_view->priv->mail_shell_sidebar;
@@ -231,7 +231,7 @@ mail_shell_view_popup_event_cb (EMailShellView *mail_shell_view,
 		return FALSE;
 
 	shell_view = E_SHELL_VIEW (mail_shell_view);
-	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content);
+	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content->view);
 	menu = e_mail_reader_get_popup_menu (reader);
 
 	e_shell_view_update_actions (shell_view);
@@ -248,27 +248,6 @@ mail_shell_view_popup_event_cb (EMailShellView *mail_shell_view,
 	return TRUE;
 }
 
-static void
-mail_shell_view_reader_changed_cb (EMailShellView *mail_shell_view,
-                                   EMailReader *reader)
-{
-	e_shell_view_update_actions (E_SHELL_VIEW (mail_shell_view));
-	e_mail_shell_view_update_sidebar (mail_shell_view);
-}
-
-static void
-mail_shell_view_reader_status_message_cb (EMailShellView *mail_shell_view,
-                                          const gchar *status_message)
-{
-	EShellView *shell_view;
-	EShellTaskbar *shell_taskbar;
-
-	shell_view = E_SHELL_VIEW (mail_shell_view);
-	shell_taskbar = e_shell_view_get_shell_taskbar (shell_view);
-
-	e_shell_taskbar_set_message (shell_taskbar, status_message);
-}
-
 static void
 mail_shell_view_scroll_cb (EMailShellView *mail_shell_view,
                            GtkOrientation orientation,
@@ -281,10 +260,13 @@ mail_shell_view_scroll_cb (EMailShellView *mail_shell_view,
 	EShellWindow *shell_window;
 	EShellSettings *shell_settings;
 	EMailReader *reader;
+	EWebView *web_view;
 	GtkWidget *message_list;
 	gboolean magic_spacebar;
 
-	if (html->binding_handled || gtk_html_get_caret_mode (html))
+	web_view = E_WEB_VIEW (html);
+
+	if (html->binding_handled || e_web_view_get_caret_mode (web_view))
 		return;
 
 	if (orientation != GTK_ORIENTATION_VERTICAL)
@@ -301,22 +283,82 @@ mail_shell_view_scroll_cb (EMailShellView *mail_shell_view,
 	if (!magic_spacebar)
 		return;
 
-	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content);
+	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content->view);
 	message_list = e_mail_reader_get_message_list (reader);
 
-	if (scroll_type == GTK_SCROLL_PAGE_FORWARD) {
-		gtk_widget_grab_focus (message_list);
+	if (scroll_type == GTK_SCROLL_PAGE_FORWARD)
 		message_list_select (
 			MESSAGE_LIST (message_list),
 			MESSAGE_LIST_SELECT_NEXT,
 			0, CAMEL_MESSAGE_SEEN);
-	} else {
-		gtk_widget_grab_focus (message_list);
+	else
 		message_list_select (
 			MESSAGE_LIST (message_list),
 			MESSAGE_LIST_SELECT_PREVIOUS,
 			0, CAMEL_MESSAGE_SEEN);
-	}
+}
+
+static void
+mail_shell_view_reader_changed_cb (EMailShellView *mail_shell_view,
+                                   EMailReader *reader)
+{
+	GtkWidget *message_list;
+	EMFormatHTML *formatter;
+	EWebView *web_view;
+	EShellView *shell_view;
+	EShellTaskbar *shell_taskbar;
+
+	shell_view = E_SHELL_VIEW (mail_shell_view);
+	shell_taskbar = e_shell_view_get_shell_taskbar (shell_view);
+
+	formatter = e_mail_reader_get_formatter (reader);
+	message_list = e_mail_reader_get_message_list (reader);
+	web_view = em_format_html_get_web_view (formatter);
+
+	e_shell_view_update_actions (E_SHELL_VIEW (mail_shell_view));
+	e_mail_shell_view_update_sidebar (mail_shell_view);
+
+	/* Connect if its not connected already */
+	if (g_signal_handler_find (
+		message_list, G_SIGNAL_MATCH_FUNC, 0, 0, NULL,
+		mail_shell_view_message_list_key_press_cb, NULL))
+		return;
+
+	g_signal_connect_swapped (
+		message_list, "key-press",
+		G_CALLBACK (mail_shell_view_message_list_key_press_cb),
+		mail_shell_view);
+
+	g_signal_connect_swapped (
+		message_list, "popup-menu",
+		G_CALLBACK (mail_shell_view_message_list_popup_menu_cb),
+		mail_shell_view);
+
+	g_signal_connect_swapped (
+		message_list, "right-click",
+		G_CALLBACK (mail_shell_view_message_list_right_click_cb),
+		mail_shell_view);
+
+	g_signal_connect_swapped (
+		web_view, "key-press-event",
+		G_CALLBACK (mail_shell_view_key_press_event_cb),
+		mail_shell_view);
+
+	g_signal_connect_swapped (
+		web_view, "popup-event",
+		G_CALLBACK (mail_shell_view_popup_event_cb),
+		mail_shell_view);
+
+	g_signal_connect_data (
+		web_view, "scroll",
+		G_CALLBACK (mail_shell_view_scroll_cb),
+		mail_shell_view, (GClosureNotify) NULL,
+		G_CONNECT_AFTER | G_CONNECT_SWAPPED);
+
+	g_signal_connect_swapped (
+		web_view, "status-message",
+		G_CALLBACK (e_shell_taskbar_set_message),
+		shell_taskbar);
 }
 
 static void
@@ -338,7 +380,7 @@ mail_shell_view_prepare_for_quit_cb (EMailShellView *mail_shell_view,
 	 * and this is the last EMailShellView instance.  Synchronize
 	 * the currently selected folder before we terminate. */
 
-	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content);
+	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content->view);
 	message_list = e_mail_reader_get_message_list (reader);
 	folder = e_mail_reader_get_folder (reader);
 
@@ -426,9 +468,10 @@ e_mail_shell_view_private_constructed (EMailShellView *mail_shell_view)
 	EShellContent *shell_content;
 	EShellSettings *shell_settings;
 	EShellSidebar *shell_sidebar;
+	EShellTaskbar *shell_taskbar;
 	EShellWindow *shell_window;
 	EShellSearchbar *searchbar;
-	EMFormatHTMLDisplay *html_display;
+	EMFormatHTML *formatter;
 	EMFolderTree *folder_tree;
 	EActionComboBox *combo_box;
 	ERuleContext *context;
@@ -447,6 +490,7 @@ e_mail_shell_view_private_constructed (EMailShellView *mail_shell_view)
 	shell_backend = e_shell_view_get_shell_backend (shell_view);
 	shell_content = e_shell_view_get_shell_content (shell_view);
 	shell_sidebar = e_shell_view_get_shell_sidebar (shell_view);
+	shell_taskbar = e_shell_view_get_shell_taskbar (shell_view);
 	shell_window = e_shell_view_get_shell_window (shell_view);
 
 	ui_manager = e_shell_window_get_ui_manager (shell_window);
@@ -469,12 +513,13 @@ e_mail_shell_view_private_constructed (EMailShellView *mail_shell_view)
 	priv->mail_shell_content = g_object_ref (shell_content);
 	priv->mail_shell_sidebar = g_object_ref (shell_sidebar);
 
-	reader = E_MAIL_READER (shell_content);
-	html_display = e_mail_reader_get_html_display (reader);
+	reader = E_MAIL_READER (E_MAIL_SHELL_CONTENT(shell_content)->view);
+	formatter = e_mail_reader_get_formatter (reader);
 	message_list = e_mail_reader_get_message_list (reader);
 
 	mail_shell_sidebar = E_MAIL_SHELL_SIDEBAR (shell_sidebar);
 	folder_tree = e_mail_shell_sidebar_get_folder_tree (mail_shell_sidebar);
+	em_folder_tree_set_selectable_widget (folder_tree, message_list);
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (folder_tree));
 
 	mail_shell_content = E_MAIL_SHELL_CONTENT (shell_content);
@@ -487,7 +532,7 @@ e_mail_shell_view_private_constructed (EMailShellView *mail_shell_view)
 		folder_tree, "sensitive",
 		combo_box, "sensitive");
 
-	web_view = E_WEB_VIEW (EM_FORMAT_HTML (html_display)->html);
+	web_view = em_format_html_get_web_view (formatter);
 
 	g_signal_connect_swapped (
 		folder_tree, "folder-selected",
@@ -573,8 +618,8 @@ e_mail_shell_view_private_constructed (EMailShellView *mail_shell_view)
 
 	g_signal_connect_swapped (
 		web_view, "status-message",
-		G_CALLBACK (mail_shell_view_reader_status_message_cb),
-		mail_shell_view);
+		G_CALLBACK (e_shell_taskbar_set_message),
+		shell_taskbar);
 
 	/* Need to keep the handler ID so we can disconnect it in
 	 * dispose().  The shell outlives us and we don't want it
@@ -585,9 +630,9 @@ e_mail_shell_view_private_constructed (EMailShellView *mail_shell_view)
 			G_CALLBACK (mail_shell_view_prepare_for_quit_cb),
 			mail_shell_view);
 
+	e_mail_reader_init (reader);
 	e_mail_shell_view_actions_init (mail_shell_view);
 	e_mail_shell_view_update_search_filter (mail_shell_view);
-	e_mail_reader_init (reader);
 
 	/* Populate built-in rules for search entry popup menu.
 	 * Keep the assertions, please.  If the conditions aren't
@@ -635,12 +680,12 @@ e_mail_shell_view_private_dispose (EMailShellView *mail_shell_view)
 		DISPOSE (priv->search_rules[ii]);
 
 	if (priv->search_account_all != NULL) {
-		camel_object_unref (priv->search_account_all);
+		g_object_unref (priv->search_account_all);
 		priv->search_account_all = NULL;
 	}
 
 	if (priv->search_account_current != NULL) {
-		camel_object_unref (priv->search_account_current);
+		g_object_unref (priv->search_account_current);
 		priv->search_account_current = NULL;
 	}
 
@@ -675,7 +720,7 @@ e_mail_shell_view_restore_state (EMailShellView *mail_shell_view)
 	mail_shell_content = mail_shell_view->priv->mail_shell_content;
 	searchbar = e_mail_shell_content_get_searchbar (mail_shell_content);
 
-	reader = E_MAIL_READER (mail_shell_content);
+	reader = E_MAIL_READER (mail_shell_content->view);
 	folder = e_mail_reader_get_folder (reader);
 	folder_uri = e_mail_reader_get_folder_uri (reader);
 
@@ -742,7 +787,7 @@ e_mail_shell_view_create_filter_from_selected (EMailShellView *mail_shell_view,
 
 	g_return_if_fail (E_IS_MAIL_SHELL_VIEW (mail_shell_view));
 
-	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content);
+	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content->view);
 	folder = e_mail_reader_get_folder (reader);
 	folder_uri = e_mail_reader_get_folder_uri (reader);
 	uids = e_mail_reader_get_selected_uids (reader);
@@ -804,7 +849,7 @@ e_mail_shell_view_create_vfolder_from_selected (EMailShellView *mail_shell_view,
 
 	g_return_if_fail (E_IS_MAIL_SHELL_VIEW (mail_shell_view));
 
-	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content);
+	reader = E_MAIL_READER (mail_shell_view->priv->mail_shell_content->view);
 	folder = e_mail_reader_get_folder (reader);
 	folder_uri = e_mail_reader_get_folder_uri (reader);
 	uids = e_mail_reader_get_selected_uids (reader);
@@ -831,12 +876,13 @@ e_mail_shell_view_update_sidebar (EMailShellView *mail_shell_view)
 	EShellView *shell_view;
 	EMailReader *reader;
 	CamelStore *local_store;
+	CamelStore *parent_store;
 	CamelFolder *folder;
 	GPtrArray *uids;
 	GString *buffer;
 	const gchar *display_name;
+	const gchar *folder_name;
 	const gchar *folder_uri;
-	gchar *folder_name;
 	gchar *title;
 	guint32 num_deleted;
 	guint32 num_junked;
@@ -851,7 +897,7 @@ e_mail_shell_view_update_sidebar (EMailShellView *mail_shell_view)
 	shell_view = E_SHELL_VIEW (mail_shell_view);
 	shell_sidebar = e_shell_view_get_shell_sidebar (shell_view);
 
-	reader = E_MAIL_READER (mail_shell_content);
+	reader = E_MAIL_READER (mail_shell_content->view);
 	folder = e_mail_reader_get_folder (reader);
 	folder_uri = e_mail_reader_get_folder_uri (reader);
 
@@ -873,15 +919,14 @@ e_mail_shell_view_update_sidebar (EMailShellView *mail_shell_view)
 		return;
 	}
 
-	camel_object_get (
-		folder, NULL,
-		CAMEL_FOLDER_NAME, &folder_name,
-		CAMEL_FOLDER_DELETED, &num_deleted,
-		CAMEL_FOLDER_JUNKED, &num_junked,
-		CAMEL_FOLDER_JUNKED_NOT_DELETED, &num_junked_not_deleted,
-		CAMEL_FOLDER_UNREAD, &num_unread,
-		CAMEL_FOLDER_VISIBLE, &num_visible,
-		NULL);
+	folder_name = camel_folder_get_name (folder);
+	parent_store = camel_folder_get_parent_store (folder);
+
+	num_deleted = folder->summary->deleted_count;
+	num_junked = folder->summary->junk_count;
+	num_junked_not_deleted = folder->summary->junk_not_deleted_count;
+	num_unread = folder->summary->unread_count;
+	num_visible = folder->summary->visible_count;
 
 	buffer = g_string_sized_new (256);
 	uids = e_mail_reader_get_selected_uids (reader);
@@ -952,7 +997,7 @@ e_mail_shell_view_update_sidebar (EMailShellView *mail_shell_view)
 	em_utils_uids_free (uids);
 
 	/* Choose a suitable folder name for displaying. */
-	if (folder->parent_store == local_store && (
+	if (parent_store == local_store && (
 		strcmp (folder_name, "Drafts") == 0 ||
 		strcmp (folder_name, "Inbox") == 0 ||
 		strcmp (folder_name, "Outbox") == 0 ||
@@ -969,6 +1014,5 @@ e_mail_shell_view_update_sidebar (EMailShellView *mail_shell_view)
 	e_shell_view_set_title (shell_view, title);
 	g_free (title);
 
-	camel_object_free (folder, CAMEL_FOLDER_NAME, folder_name);
 	g_string_free (buffer, TRUE);
 }
