@@ -335,12 +335,11 @@ static GtkActionEntry mailing_list_entries[] = {
 
 static void
 update_actions_cb (EMailReader *reader,
+                   guint32 state,
                    GtkActionGroup *action_group)
 {
 	gboolean sensitive;
-	guint32 state;
 
-	state = e_mail_reader_check_state (reader);
 	sensitive = (state & E_MAIL_READER_SELECTION_IS_MAILING_LIST);
 	gtk_action_group_set_sensitive (action_group, sensitive);
 }
