@@ -41,6 +41,7 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include "mail/em-config.h"
+#include "shell/e-shell.h"
 
 #include <gconf/gconf-client.h>
 
@@ -185,12 +186,13 @@ pipe_to_sa_full (CamelMimeMessage *msg, const gchar *in, const gchar **argv, gin
 	if (msg) {
 		stream = camel_stream_fs_new_with_fd (fds[1]);
 
-		camel_data_wrapper_write_to_stream (CAMEL_DATA_WRAPPER (msg), stream);
-		camel_stream_flush (stream);
-		camel_stream_close (stream);
+		camel_data_wrapper_write_to_stream (
+			CAMEL_DATA_WRAPPER (msg), stream, NULL);
+		camel_stream_flush (stream, NULL);
+		camel_stream_close (stream, NULL);
 		g_object_unref (stream);
 	} else if (in) {
-		camel_write (fds[1], in, strlen (in));
+		camel_write (fds[1], in, strlen (in), NULL);
 		close (fds[1]);
 	}
 
@@ -202,7 +204,7 @@ pipe_to_sa_full (CamelMimeMessage *msg, const gchar *in, const gchar **argv, gin
 		memstream = (CamelStreamMem *) camel_stream_mem_new ();
 		camel_stream_mem_set_byte_array (memstream, output_buffer);
 
-		camel_stream_write_to_stream (stream, (CamelStream *) memstream);
+		camel_stream_write_to_stream (stream, (CamelStream *) memstream, NULL);
 		g_object_unref (stream);
 		g_byte_array_append (output_buffer, (guchar *)"", 1);
 
@@ -366,7 +368,7 @@ em_junk_sa_run_spamd (const gchar *binary)
 		time_req.tv_sec = 0;
 		time_req.tv_nsec = 50000000;
 
-		for (i = 0; i < 100; i ++) {
+		for (i = 0; i < 100; i++) {
 			if (stat (em_junk_sa_get_socket_path (), &stat_buf) == 0) {
 				d(fprintf (stderr, "socket created\n"));
 				break;
@@ -393,7 +395,7 @@ em_junk_sa_start_own_daemon ()
 	em_junk_sa_socket_path = e_mktemp ("spamd-socket-path-XXXXXX");
 	em_junk_sa_spamd_pidfile = e_mktemp ("spamd-pid-file-XXXXXX");
 
-	for (b = 0; em_junk_sa_spamd_binaries [b]; b ++) {
+	for (b = 0; em_junk_sa_spamd_binaries [b]; b++) {
 		em_junk_sa_use_spamc = em_junk_sa_run_spamd (em_junk_sa_spamd_binaries [b]);
 		if (em_junk_sa_use_spamc) {
 			em_junk_sa_new_daemon_started = TRUE;
@@ -409,7 +411,7 @@ em_junk_sa_find_spamc ()
 		gint b;
 
 		em_junk_sa_use_spamc = FALSE;
-		for (b = 0; em_junk_sa_spamc_binaries [b]; b ++) {
+		for (b = 0; em_junk_sa_spamc_binaries [b]; b++) {
 			em_junk_sa_spamc_binary = em_junk_sa_spamc_binaries [b];
 			if (em_junk_sa_test_spamd_running (em_junk_sa_spamc_binary, FALSE)) {
 				em_junk_sa_use_spamc = TRUE;
@@ -454,7 +456,7 @@ em_junk_sa_test_spamd (void)
 
 	/* try to use sytem spamd first */
 	if (try_system_spamd) {
-		for (b = 0; em_junk_sa_spamc_binaries [b]; b ++) {
+		for (b = 0; em_junk_sa_spamc_binaries [b]; b++) {
 			em_junk_sa_spamc_binary = em_junk_sa_spamc_binaries [b];
 			if (em_junk_sa_test_spamd_running (em_junk_sa_spamc_binary, TRUE)) {
 				em_junk_sa_use_spamc = TRUE;
@@ -466,7 +468,7 @@ em_junk_sa_test_spamd (void)
 
 	/* if there's no system spamd running, try to use user one with user specified socket */
 	if (!em_junk_sa_use_spamc && em_junk_sa_preferred_socket_path) {
-		for (b = 0; em_junk_sa_spamc_binaries [b]; b ++) {
+		for (b = 0; em_junk_sa_spamc_binaries [b]; b++) {
 			em_junk_sa_spamc_binary = em_junk_sa_spamc_binaries [b];
 			if (em_junk_sa_test_spamd_running (em_junk_sa_spamc_binary, FALSE)) {
 				em_junk_sa_use_spamc = TRUE;
@@ -530,7 +532,7 @@ em_junk_sa_check_respawn_too_fast ()
 		rv = FALSE;
 
 	em_junk_sa_spamd_restarts [em_junk_sa_spamd_restarts_count % SPAMD_RESTARTS_SIZE] = time_now;
-	em_junk_sa_spamd_restarts_count ++;
+	em_junk_sa_spamd_restarts_count++;
 
 	G_UNLOCK (spamd_restart);
 
@@ -920,6 +922,7 @@ use_remote_tests_cb (GtkWidget *widget, gpointer data)
 GtkWidget *
 org_gnome_sa_use_remote_tests (struct _EPlugin *epl, struct _EConfigHookItemFactoryData *data)
 {
+	EShell *shell;
 	GtkWidget *check, *vbox, *label;
 	gchar *text = g_strdup_printf ("    <small>%s</small>", _("This will make SpamAssassin more reliable, but slower"));
 	guint n_rows;
@@ -942,7 +945,13 @@ org_gnome_sa_use_remote_tests (struct _EPlugin *epl, struct _EConfigHookItemFact
 	gtk_table_attach (
 		GTK_TABLE (data->parent), vbox,
 		0, 1, n_rows, n_rows+1, 0, 0, 0, 0);
-	gtk_widget_show_all (vbox);
-	return (GtkWidget *)vbox;
+
+	shell = e_shell_get_default ();
+	if (e_shell_get_express_mode (shell))
+		gtk_widget_hide (vbox);
+	else
+		gtk_widget_show_all (vbox);
+
+	return vbox;
 }
 
