@@ -303,13 +303,11 @@ exit:
 /**
  * e_shell_utils_import_uris:
  * @shell: The #EShell instance
- * @uris: %NULL-terminated list of URIs to import or preview
- * @preview: rather preview than import given URIs
+ * @uris: %NULL-terminated list of URIs to import
  *
  * Imports given URIs to Evolution, giving user a choice what to import
  * if more than one importer can be applied, and where to import it, if
- * the importer itself is configurable. It can preview data, instead of
- * importing if requested and the imported has that implemented.
+ * the importer itself is configurable.
  *
  * URIs should be either a filename or URI of form file://.
  * All others are skipped.
@@ -317,7 +315,8 @@ exit:
  * Returns: the number of URIs successfully handled
  **/
 guint
-e_shell_utils_import_uris (EShell *shell, gchar **uris, gboolean preview)
+e_shell_utils_import_uris (EShell *shell,
+                           gchar **uris)
 {
 	GtkWindow *parent;
 	GtkWidget *assistant;
@@ -326,7 +325,7 @@ e_shell_utils_import_uris (EShell *shell, gchar **uris, gboolean preview)
 	g_return_val_if_fail (uris != NULL, 0);
 
 	parent = e_shell_get_active_window (shell);
-	assistant = e_import_assistant_new_simple (parent, uris, preview);
+	assistant = e_import_assistant_new_simple (parent, uris);
 
 	if (assistant) {
 		g_signal_connect_after (
@@ -340,11 +339,62 @@ e_shell_utils_import_uris (EShell *shell, gchar **uris, gboolean preview)
 		e_shell_watch_window (shell, GTK_WINDOW (assistant));
 
 		gtk_widget_show (assistant);
-	} else {
-		g_warning (
-			"%s: Cannot %s any of the given URIs",
-			G_STRFUNC, preview ? "preview" : "import");
-	}
+	} else
+		g_warning ("Cannot import any of the given URIs");
 
 	return g_strv_length (uris);
 }
+
+/**
+ * e_shell_hide_widgets_for_express_mode:
+ * @shell: an #EShell
+ * @builder: a #GtkBuilder
+ * @widget_name: NULL-terminated list of strings
+ *
+ * If Evolution is running in Express mode (i.e. if the specified @shell is
+ * in Express mode), then this function will hide a list of widgets, based
+ * on their specified names.  The list of names must be NULL-terminated,
+ * and each element of that list must be the name of a widget present in
+ * @builder.  Those widgets will then get hidden.
+ *
+ * This can be used to simplify preference dialogs and such in an easy
+ * fashion, for use in Express mode.
+ *
+ * If Evolution is not running in Express mode, this function does nothing.
+ */
+void
+e_shell_hide_widgets_for_express_mode (EShell *shell,
+                                       GtkBuilder *builder,
+                                       const gchar *widget_name,
+                                       ...)
+{
+	va_list args;
+
+	g_return_if_fail (E_IS_SHELL (shell));
+	g_return_if_fail (GTK_IS_BUILDER (builder));
+	g_return_if_fail (widget_name != NULL);
+
+	if (!e_shell_get_express_mode (shell))
+		return;
+
+	va_start (args, widget_name);
+
+	while (widget_name != NULL) {
+		GObject *object;
+
+		object = gtk_builder_get_object (builder, widget_name);
+		if (!GTK_IS_WIDGET (object)) {
+			g_error (
+				"Object '%s' was not found in the builder "
+				"file, or it is not a GtkWidget", widget_name);
+			g_assert_not_reached ();
+		}
+
+		gtk_widget_hide (GTK_WIDGET (object));
+
+		widget_name = va_arg (args, const gchar *);
+	}
+
+	va_end (args);
+}
+
