@@ -118,6 +118,13 @@ gchar **	e_attachment_store_get_uris_finish
 						(EAttachmentStore *store,
 						 GAsyncResult *result,
 						 GError **error);
+void		e_attachment_store_load_async	(EAttachmentStore *store,
+						 GList *attachment_list,
+						 GAsyncReadyCallback callback,
+						 gpointer user_data);
+gboolean	e_attachment_store_load_finish	(EAttachmentStore *store,
+						 GAsyncResult *result,
+						 GError **error);
 void		e_attachment_store_save_async	(EAttachmentStore *store,
 						 GFile *destination,
 						 GAsyncReadyCallback callback,
