@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -80,11 +80,14 @@ esm_dispose (GObject *object)
 }
 
 static void
-esm_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
+esm_get_property (GObject *object,
+                  guint prop_id,
+                  GValue *value,
+                  GParamSpec *pspec)
 {
 	ESelectionModel *esm = E_SELECTION_MODEL (object);
 
-	switch (prop_id){
+	switch (prop_id) {
 	case PROP_SORTER:
 		g_value_set_object (value, esm->sorter);
 		break;
@@ -100,21 +103,26 @@ esm_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *psp
 }
 
 static void
-esm_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
+esm_set_property (GObject *object,
+                  guint prop_id,
+                  const GValue *value,
+                  GParamSpec *pspec)
 {
 	ESelectionModel *esm = E_SELECTION_MODEL (object);
 
-	switch (prop_id){
+	switch (prop_id) {
 	case PROP_SORTER:
 		drop_sorter(esm);
-		add_sorter(esm, g_value_get_object (value) ? E_SORTER(g_value_get_object(value)) : NULL);
+		add_sorter (
+			esm, g_value_get_object (value) ?
+			E_SORTER (g_value_get_object (value)) : NULL);
 		break;
 
 	case PROP_SELECTION_MODE:
 		esm->mode = g_value_get_int (value);
 		if (esm->mode == GTK_SELECTION_SINGLE) {
-			int cursor_row = e_selection_model_cursor_row(esm);
-			int cursor_col = e_selection_model_cursor_col(esm);
+			gint cursor_row = e_selection_model_cursor_row(esm);
+			gint cursor_col = e_selection_model_cursor_col(esm);
 			e_selection_model_do_something(esm, cursor_row, cursor_col, 0);
 		}
 		break;
@@ -205,23 +213,23 @@ e_selection_model_class_init (ESelectionModelClass *klass)
 
 	g_object_class_install_property (object_class, PROP_SORTER,
 					 g_param_spec_object ("sorter",
-							      _("Sorter"),
-							      /*_( */"XXX blurb" /*)*/,
+							      "Sorter",
+							      NULL,
 							      E_SORTER_TYPE,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_SELECTION_MODE,
 					 g_param_spec_int ("selection_mode",
-							   _("Selection Mode"),
-							   /*_( */"XXX blurb" /*)*/,
+							   "Selection Mode",
+							   NULL,
 							   GTK_SELECTION_NONE, GTK_SELECTION_MULTIPLE,
 							   GTK_SELECTION_SINGLE,
 							   G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class, PROP_CURSOR_MODE,
 					 g_param_spec_int ("cursor_mode",
-							   _("Cursor Mode"),
-							   /*_( */"XXX blurb" /*)*/,
+							   "Cursor Mode",
+							   NULL,
 							   E_CURSOR_LINE, E_CURSOR_SPREADSHEET,
 							   E_CURSOR_LINE,
 							   G_PARAM_READWRITE));
@@ -322,7 +330,7 @@ e_selection_model_invert_selection (ESelectionModel *selection)
 		E_SELECTION_MODEL_GET_CLASS(selection)->invert_selection (selection);
 }
 
-int
+gint
 e_selection_model_row_count (ESelectionModel *selection)
 {
 	if (E_SELECTION_MODEL_GET_CLASS(selection)->row_count)
@@ -332,20 +340,20 @@ e_selection_model_row_count (ESelectionModel *selection)
 }
 
 void
-e_selection_model_change_one_row(ESelectionModel *selection, int row, gboolean grow)
+e_selection_model_change_one_row(ESelectionModel *selection, gint row, gboolean grow)
 {
 	if (E_SELECTION_MODEL_GET_CLASS(selection)->change_one_row)
 		E_SELECTION_MODEL_GET_CLASS(selection)->change_one_row (selection, row, grow);
 }
 
 void
-e_selection_model_change_cursor (ESelectionModel *selection, int row, int col)
+e_selection_model_change_cursor (ESelectionModel *selection, gint row, gint col)
 {
 	if (E_SELECTION_MODEL_GET_CLASS(selection)->change_cursor)
 		E_SELECTION_MODEL_GET_CLASS(selection)->change_cursor (selection, row, col);
 }
 
-int
+gint
 e_selection_model_cursor_row (ESelectionModel *selection)
 {
 	if (E_SELECTION_MODEL_GET_CLASS(selection)->cursor_row)
@@ -354,7 +362,7 @@ e_selection_model_cursor_row (ESelectionModel *selection)
 		return -1;
 }
 
-int
+gint
 e_selection_model_cursor_col (ESelectionModel *selection)
 {
 	if (E_SELECTION_MODEL_GET_CLASS(selection)->cursor_col)
@@ -364,28 +372,28 @@ e_selection_model_cursor_col (ESelectionModel *selection)
 }
 
 void
-e_selection_model_select_single_row (ESelectionModel *selection, int row)
+e_selection_model_select_single_row (ESelectionModel *selection, gint row)
 {
 	if (E_SELECTION_MODEL_GET_CLASS(selection)->select_single_row)
 		E_SELECTION_MODEL_GET_CLASS(selection)->select_single_row (selection, row);
 }
 
 void
-e_selection_model_toggle_single_row (ESelectionModel *selection, int row)
+e_selection_model_toggle_single_row (ESelectionModel *selection, gint row)
 {
 	if (E_SELECTION_MODEL_GET_CLASS(selection)->toggle_single_row)
 		E_SELECTION_MODEL_GET_CLASS(selection)->toggle_single_row (selection, row);
 }
 
 void
-e_selection_model_move_selection_end (ESelectionModel *selection, int row)
+e_selection_model_move_selection_end (ESelectionModel *selection, gint row)
 {
 	if (E_SELECTION_MODEL_GET_CLASS(selection)->move_selection_end)
 		E_SELECTION_MODEL_GET_CLASS(selection)->move_selection_end (selection, row);
 }
 
 void
-e_selection_model_set_selection_end (ESelectionModel *selection, int row)
+e_selection_model_set_selection_end (ESelectionModel *selection, gint row)
 {
 	if (E_SELECTION_MODEL_GET_CLASS(selection)->set_selection_end)
 		E_SELECTION_MODEL_GET_CLASS(selection)->set_selection_end (selection, row);
@@ -409,7 +417,7 @@ e_selection_model_do_something (ESelectionModel *selection,
 {
 	gint shift_p = state & GDK_SHIFT_MASK;
 	gint ctrl_p = state & GDK_CONTROL_MASK;
-	int row_count;
+	gint row_count;
 
 	selection->old_selection = -1;
 
@@ -511,7 +519,7 @@ e_selection_model_select_as_key_press (ESelectionModel *selection,
 				       guint            col,
 				       GdkModifierType  state)
 {
-	int cursor_activated = TRUE;
+	gint cursor_activated = TRUE;
 
 	gint shift_p = state & GDK_SHIFT_MASK;
 	gint ctrl_p = state & GDK_CONTROL_MASK;
@@ -552,9 +560,9 @@ move_selection (ESelectionModel *selection,
 		gboolean              up,
 		GdkModifierType       state)
 {
-	int row = e_selection_model_cursor_row(selection);
-	int col = e_selection_model_cursor_col(selection);
-	int row_count;
+	gint row = e_selection_model_cursor_row(selection);
+	gint col = e_selection_model_cursor_col(selection);
+	gint row_count;
 
 	/* there is no selected row when row is -1 */
 	if (row != -1)
@@ -601,8 +609,8 @@ e_selection_model_key_press      (ESelectionModel *selection,
 	case GDK_space:
 	case GDK_KP_Space:
 		if (selection->mode != GTK_SELECTION_SINGLE) {
-			int row = e_selection_model_cursor_row(selection);
-			int col = e_selection_model_cursor_col(selection);
+			gint row = e_selection_model_cursor_row(selection);
+			gint col = e_selection_model_cursor_col(selection);
 			if (row == -1)
 				break;
 
@@ -616,8 +624,8 @@ e_selection_model_key_press      (ESelectionModel *selection,
 	case GDK_Return:
 	case GDK_KP_Enter:
 		if (selection->mode != GTK_SELECTION_SINGLE) {
-			int row = e_selection_model_cursor_row(selection);
-			int col = e_selection_model_cursor_col(selection);
+			gint row = e_selection_model_cursor_row(selection);
+			gint col = e_selection_model_cursor_col(selection);
 			e_selection_model_select_single_row (selection, row);
 			g_signal_emit(selection,
 				      e_selection_model_signals[CURSOR_ACTIVATED], 0,
@@ -628,8 +636,8 @@ e_selection_model_key_press      (ESelectionModel *selection,
 	case GDK_Home:
 	case GDK_KP_Home:
 		if (selection->cursor_mode == E_CURSOR_LINE) {
-			int row = 0;
-			int cursor_col = e_selection_model_cursor_col(selection);
+			gint row = 0;
+			gint cursor_col = e_selection_model_cursor_col(selection);
 
 			row = e_sorter_sorted_to_model(selection->sorter, row);
 			e_selection_model_select_as_key_press (selection, row, cursor_col, key->state);
@@ -639,8 +647,8 @@ e_selection_model_key_press      (ESelectionModel *selection,
 	case GDK_End:
 	case GDK_KP_End:
 		if (selection->cursor_mode == E_CURSOR_LINE) {
-			int row = e_selection_model_row_count(selection) - 1;
-			int cursor_col = e_selection_model_cursor_col(selection);
+			gint row = e_selection_model_row_count(selection) - 1;
+			gint cursor_col = e_selection_model_cursor_col(selection);
 
 			row = e_sorter_sorted_to_model(selection->sorter, row);
 			e_selection_model_select_as_key_press (selection, row, cursor_col, key->state);
@@ -653,8 +661,8 @@ e_selection_model_key_press      (ESelectionModel *selection,
 
 void
 e_selection_model_cursor_changed      (ESelectionModel *selection,
-				       int              row,
-				       int              col)
+				       gint              row,
+				       gint              col)
 {
 	g_signal_emit(selection,
 		      e_selection_model_signals[CURSOR_CHANGED], 0,
@@ -663,8 +671,8 @@ e_selection_model_cursor_changed      (ESelectionModel *selection,
 
 void
 e_selection_model_cursor_activated    (ESelectionModel *selection,
-				       int              row,
-				       int              col)
+				       gint              row,
+				       gint              col)
 {
 	g_signal_emit(selection,
 		      e_selection_model_signals[CURSOR_ACTIVATED], 0,
@@ -680,7 +688,7 @@ e_selection_model_selection_changed   (ESelectionModel *selection)
 
 void
 e_selection_model_selection_row_changed (ESelectionModel *selection,
-					 int              row)
+					 gint              row)
 {
 	g_signal_emit(selection,
 		      e_selection_model_signals[SELECTION_ROW_CHANGED], 0,
