@@ -111,7 +111,7 @@ etsp_init (ETableSpecification *etsp)
 ETableSpecification *
 e_table_specification_new (void)
 {
-	ETableSpecification *etsp = g_object_new (E_TABLE_SPECIFICATION_TYPE, NULL);
+	ETableSpecification *etsp = g_object_new (E_TYPE_TABLE_SPECIFICATION, NULL);
 
 	return (ETableSpecification *) etsp;
 }
